aboutsummaryrefslogtreecommitdiff
path: root/sys/dev/pcm
diff options
context:
space:
mode:
authorRoger Hardiman <roger@FreeBSD.org>1999-05-27 06:12:40 +0000
committerRoger Hardiman <roger@FreeBSD.org>1999-05-27 06:12:40 +0000
commit229cf3c3357280d64aaba05bc837561d570031e4 (patch)
tree64dcc93e6e77201e2081d76a29ec907c4555ad03 /sys/dev/pcm
parentb5fcc9783fbb1c378425fefde3f1212eb4b53eda (diff)
Notes
Diffstat (limited to 'sys/dev/pcm')
-rw-r--r--sys/dev/pcm/isa/sb.c12
1 files changed, 8 insertions, 4 deletions
diff --git a/sys/dev/pcm/isa/sb.c b/sys/dev/pcm/isa/sb.c
index 9e453a281eec..7544dae73327 100644
--- a/sys/dev/pcm/isa/sb.c
+++ b/sys/dev/pcm/isa/sb.c
@@ -1271,9 +1271,10 @@ ess1868_attach(u_long csn, u_long vend_id, char *name,
/*
* A driver for some SB16pnp and compatibles...
*
* Avance Asound 100 -- 0x01009305
* Avance Logic ALS100+ -- 0x10019305
* xxx -- 0x2b008c0e
*
*/
@@ -1311,6 +1312,8 @@ sb16pnp_probe(u_long csn, u_long vend_id)
s = "Avance Asound 100" ;
else if (vend_id == 0x10019305)
s = "Avance Logic 100+" ; /* Vibra16X-class */
+ else if (vend_id == 0x20019305)
+ s = "Avance Logic ALS120" ; /* Vibra16X-class */
if (s) {
struct pnp_cinfo d;
read_pnp_parms(&d, 0);
@@ -1348,7 +1351,8 @@ sb16pnp_attach(u_long csn, u_long vend_id, char *name,
pcm_info[dev->id_unit] = tmp_d; /* pcm_info[] will be reinitialized after */
snddev_last_probed->probe(dev); /* not really necessary but doesn't harm */
- if (vend_id == 0x10019305 || vend_id == 0xf0008c0e) {
+ if (vend_id == 0x10019305 || vend_id == 0xf0008c0e
+ || vend_id == 0x20019305) {
/*
* XXX please add here the vend_id for other vibra16X cards...
* And remember, must change tmp_d, not
@@ -1271,9 +1271,10 @@ ess1868_attach(u_long csn, u_long vend_id, char *name,
* A driver for some SB16pnp and compatibles...
*
- * Avance Asound 100 -- 0x01009305
- * Avance Logic ALS100+ -- 0x10019305
- * xxx -- 0x2b008c0e
+ * Avance Asound 100 -- 0x01009305
+ * Avance Logic ALS100+ -- 0x10019305
+ * Avance Logic ASound Gold ALS120 -- 0x20019305
+ * xxx -- 0x2b008c0e
*
*/